summaryrefslogtreecommitdiff
path: root/xmake/scripts/platform/linux/_linux.lua
diff options
context:
space:
mode:
Diffstat (limited to 'xmake/scripts/platform/linux/_linux.lua')
-rw-r--r--xmake/scripts/platform/linux/_linux.lua12
1 files changed, 6 insertions, 6 deletions
diff --git a/xmake/scripts/platform/linux/_linux.lua b/xmake/scripts/platform/linux/_linux.lua
index b933d563b..391a4d2cd 100644
--- a/xmake/scripts/platform/linux/_linux.lua
+++ b/xmake/scripts/platform/linux/_linux.lua
@@ -38,11 +38,11 @@ _linux._PROBER = require("platform/linux/_prober")
-- make configure
function _linux.make(configs)
- -- init the file name formats
- configs.formats = {}
- configs.formats.static = {"lib", ".a"}
- configs.formats.object = {"", ".o"}
- configs.formats.shared = {"", ".so"}
+ -- init the file name format
+ configs.format = {}
+ configs.format.static = {"lib", ".a"}
+ configs.format.object = {"", ".o"}
+ configs.format.shared = {"", ".so"}
end
-- get the option menu for action: xmake config or global
@@ -51,7 +51,7 @@ function _linux.menu(action)
-- init config option menu
_linux._MENU_CONFIG = _linux._MENU_CONFIG or
{ {}
- , {nil, "ar", "kv", "ar", "The Library Creator" }
+ , {nil, "ar", "kv", nil, "The Library Creator" }
, {nil, "arflags", "kv", nil, "The Library Creator Flags" }
}